@@ -948,15 +948,15 @@ def ges(data, method='complete', score='default', prune=True, thres=0.1, debug=F
     return post_process(cpdag, dc)
 
 
-def sed(graph, data):
+def sed(learned_dag, data):
     '''
 
-    :param dag: the original learned graph
+    :param dag: the original learned DAG
     :param data: input training data (unique version)
     :return: corrected CPDAG
     '''
-    if type(graph) is str:
-        learned_dag = from_bnlearn(graph)
+    if type(learned_dag) is str:
+        learned_dag = from_bnlearn(learned_dag)
     elif type(graph) is not dict:
         raise Exception('The format of input graph is invalid.')
     # remove unused states
